@@ -60,7 +60,7 @@ def console_command():
 		org_yaml_filename = arg_ls[1]
 		output_js_filename = (arg_ls[2] if arg_len >= 3 else None)
 		# RangeCSSのyaml帳票をjsに変換 [range_css_compiler]
-		range_css_compiler.compile(
+		compile(
 			org_yaml_filename = org_yaml_filename,
 			output_js_filename = output_js_filename,
 		)
